@@ -18,7 +18,7 @@
  *
  * May, 2000. Implemented on FreeBSD 4.0-RELEASE (Compaq Armada M700)
  *
-$Id: properties.c,v 1.42 2005/01/11 06:17:09 ryanl Exp $
+$Id: properties.c,v 1.43 2005/01/13 13:17:07 bdejean Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -85,6 +85,7 @@ hard_set_sensitive (GtkWidget *w, gboolean sensitivity)
 }
 
 
+#if 0
 /* set sensitive, but always insensitive if NEVER_SENSITIVE is set */
 static void
 soft_set_sensitive (GtkWidget *w, gboolean sensitivity)
@@ -94,6 +95,7 @@ soft_set_sensitive (GtkWidget *w, gboolean sensitivity)
 	else
 		gtk_widget_set_sensitive (w, sensitivity);
 }
+#endif /* 0 */
 
 static gboolean
 key_writable (PanelApplet *applet, const char *key)
@@ -291,11 +293,8 @@ prop_cb (BonoboUIComponent *uic,
 {
   GladeXML  *glade_xml;
   GtkWidget *layout_table;
-  GtkWidget *preview_hbox;
-  GtkWidget *widget;
   GConfClient *client;
   gboolean   inhibit_command_line;
-  AtkObject *atk_widget;
 
   client = gconf_client_get_default ();
   inhibit_command_line = gconf_client_get_bool (client, "/desktop/gnome/lockdown/inhibit_command_line", NULL);
