@@ -50,6 +50,10 @@ static gboolean	gnome_volume_applet_button	(GtkWidget *widget,
 static gboolean	gnome_volume_applet_key		(GtkWidget *widget,
 						 GdkEventKey *event);
 
+static void	gnome_volume_applet_background	(PanelApplet *panel_applet,
+						 PanelAppletBackgroundType type,
+						 GdkColor  *colour,
+						 GdkPixmap *pixmap);
 static void	gnome_volume_applet_orientation	(PanelApplet *applet,
 						 PanelAppletOrient orient);
 static void	gnome_volume_applet_size	(PanelApplet *applet,
@@ -81,11 +85,11 @@ static struct {
   gchar *filename;
   GdkPixbuf *pixbuf;
 } pix[] = {
-  { PIXDIR "/volume-mute.png",   NULL },
-  { PIXDIR "/volume-zero.png",   NULL },
-  { PIXDIR "/volume-min.png",    NULL },
-  { PIXDIR "/volume-medium.png", NULL },
-  { PIXDIR "/volume-max.png",    NULL },
+  { GNOME_PIXMAPSDIR "/mixer/volume-mute.png",   NULL },
+  { GNOME_PIXMAPSDIR "/mixer/volume-zero.png",   NULL },
+  { GNOME_PIXMAPSDIR "/mixer/volume-min.png",    NULL },
+  { GNOME_PIXMAPSDIR "/mixer/volume-medium.png", NULL },
+  { GNOME_PIXMAPSDIR "/mixer/volume-max.png",    NULL },
   { NULL, NULL }
 };
 
@@ -174,9 +178,10 @@ gnome_volume_applet_class_init (GnomeVolumeAppletClass *klass)
   gtkwidget_class->scroll_event = gnome_volume_applet_scroll;
   panelapplet_class->change_orient = gnome_volume_applet_orientation;
   panelapplet_class->change_size = gnome_volume_applet_size;
+  panelapplet_class->change_background = gnome_volume_applet_background;
 
   /* FIXME:
-   * - style-set, change-background.
+   * - style-set.
    */
 
   /* init pixbufs */
@@ -326,7 +331,7 @@ gnome_volume_applet_setup (GnomeVolumeApplet *applet,
 
   /* menu - done here because bonobo is intialized now */
   panel_applet_setup_menu_from_file (PANEL_APPLET (applet), 
-				     NULL,
+				     DATADIR,
 				     "GNOME_MixerApplet.xml",
 				     NULL, verbs, applet);
   component = panel_applet_get_popup_component (PANEL_APPLET (applet));
@@ -731,6 +736,39 @@ gnome_volume_applet_size (PanelApplet *applet,
     PANEL_APPLET_CLASS (parent_class)->change_size (applet, size);
 }
 
+static void
+gnome_volume_applet_background (PanelApplet *_applet,
+				PanelAppletBackgroundType type,
+				GdkColor  *colour,
+				GdkPixmap *pixmap)
+{
+  GnomeVolumeApplet *applet = GNOME_VOLUME_APPLET (_applet);
+  GtkRcStyle *rc_style;
+  GtkStyle *style;
+
+  /* reset style */
+  gtk_widget_set_style (GTK_WIDGET (applet), NULL);
+  rc_style = gtk_rc_style_new ();
+  gtk_widget_modify_style (GTK_WIDGET (applet), rc_style);
+  g_object_unref (rc_style);
+
+  switch (type) {
+    case PANEL_NO_BACKGROUND:
+      break;
+    case PANEL_COLOR_BACKGROUND:
+      gtk_widget_modify_bg (GTK_WIDGET (applet),
+			    GTK_STATE_NORMAL, colour);
+      break;
+    case PANEL_PIXMAP_BACKGROUND:
+      style = gtk_style_copy (GTK_WIDGET (applet)->style);
+      if (style->bg_pixmap[GTK_STATE_NORMAL])
+        g_object_unref (style->bg_pixmap[GTK_STATE_NORMAL]);
+      style->bg_pixmap[GTK_STATE_NORMAL] = g_object_ref (pixmap);
+      gtk_widget_set_style (GTK_WIDGET (applet), style);
+      break;
+  }
+}
+
 /*
  * Volume changed.
  */
@@ -782,6 +820,8 @@ gnome_volume_applet_refresh (GnomeVolumeApplet *applet)
   g_free (volumes);
   mute = GST_MIXER_TRACK_HAS_FLAG (applet->track,
 				   GST_MIXER_TRACK_MUTE);
+  if (volume == 0)
+    mute = TRUE;
 
   n = 4 * volume / (applet->track->max_volume -
       applet->track->min_volume) + 1;
@@ -792,7 +832,7 @@ gnome_volume_applet_refresh (GnomeVolumeApplet *applet)
 
   if (STATE (n, mute) != applet->state) {
     if (mute) {
-      orig = gdk_pixbuf_copy (pix[n].pixbuf);
+      orig = gdk_pixbuf_copy (pix[applet->state >> 1].pixbuf);
       gdk_pixbuf_composite (pix[0].pixbuf, orig, 0, 0,
 			    gdk_pixbuf_get_width (orig),
 			    gdk_pixbuf_get_height (orig),
@@ -814,7 +854,8 @@ gnome_volume_applet_refresh (GnomeVolumeApplet *applet)
   }
 
   applet->lock = TRUE;
-  gtk_range_set_value (applet->dock->scale, volume);
+  if (volume > 0)
+    gtk_range_set_value (applet->dock->scale, volume);
   applet->lock = FALSE;
 
   /* update mute status (bonobo) */
@@ -964,25 +1005,21 @@ cb_verb (BonoboUIComponent *uic,
       g_error_free (error);
     }
   } else if (!strcmp (verbname, "About")) {
-    GtkWidget *about;
-    GdkPixbuf *pixbuf;
+	  
     const gchar *authors[] = { "Ronald Bultje <rbultje@ronald.bitfreak.net>",
 			     NULL };
 
-    pixbuf = gtk_icon_theme_load_icon (gtk_icon_theme_get_default (),
-		    "gnome-mixer-applet", 48, 0, NULL);
-    
-    about = gnome_about_new (_("Volume Applet"),
-			     VERSION,
-			     "(c) 2004 Ronald Bultje",
-			     _("A GNOME/GStreamer-based volume control applet"),
-			     authors, NULL, NULL,
-			     pixbuf);
+    gtk_show_about_dialog (NULL,
+		"name",		_("Volume Applet"),
+		"version",	VERSION,
+		"copyright",	"\xC2\xA9 2004 Ronald Bultje",
+		"comments",	_("A GNOME/GStreamer-based volume control "
+				  "applet"),
+		"authors",	authors,
+		"translator-credits",	_("translator-credits"),
+		"logo-icon-name",	"gnome-mixer-applet",
+		NULL);
 
-    if (pixbuf)
-	    g_object_unref (pixbuf);
-
-    gtk_widget_show (about);
   } else if (!strcmp (verbname, "Pref")) {
     if (applet->prefs)
       return;
