@@ -26,7 +26,7 @@
 #include <glade/glade.h>
 
 #define GCONF_PATH	"/apps/stickynotes_applet"
-#define GLADE_PATH	STICKYNOTES_GLADEDIR "/stickynotes.glade"
+#define GLADE_PATH	GNOME_GLADEDIR "/stickynotes.glade"
 #define XML_PATH	"/.gnome2/stickynotes_applet"
 #define ICON_PATH	STICKYNOTES_ICONDIR
 
@@ -45,10 +45,10 @@ typedef struct
 	GtkAdjustment *w_prefs_width;
 	GtkAdjustment *w_prefs_height;
 	GtkWidget *w_prefs_color;
+	GtkWidget *w_prefs_font_color;
 	GtkWidget *w_prefs_sys_color;
 	GtkWidget *w_prefs_font;
 	GtkWidget *w_prefs_sys_font;
-	GtkWidget *w_prefs_click;
 	GtkWidget *w_prefs_sticky;
 	GtkWidget *w_prefs_force;
 
@@ -60,7 +60,6 @@ typedef struct
 
 	GConfClient *gconf;		/* GConf Client */
 	GtkTooltips *tooltips;		/* Tooltips */
-
 } StickyNotes;
 
 /* Sticky Notes Icons */
@@ -85,7 +84,10 @@ typedef struct
 
 	gint panel_size;
 	PanelAppletOrient panel_orient;
-
+	
+	GtkWidget *popup_menu;			/* Popup Menu */
+	GtkWidget *menu_tip;
+	GtkWidget *menu_show;
 } StickyNotesApplet;
 	
 typedef enum
